/*
 * MIT License
 *
 * Copyright (c) 2021 Siddhesh Patil, Siddroid.com
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

package com.siddroid.holi.colors

import androidx.compose.ui.graphics.Color

/**
 *
 * @author Siddhesh Patil
 * Siddroid.com
 * @since 27-03-2021
 *
 * A collection of known material colors with their accents
 * Colors with no shade number are of 500 shade as default
 *
 */
object MaterialColor {

    val WHITE = Color(0xffffffff)


    // RED MATERIAL COLORS
    val RED = Color(0xfff44336)
    val RED_50 = Color(0xffffebee)
    val RED_100 = Color(0xffffcdd2)
    val RED_200 = Color(0xffef9a9a)
    val RED_300 = Color(0xffe57373)
    val RED_400 = Color(0xffef5350)
    val RED_500 = Color(0xfff44336)
    val RED_600 = Color(0xffe53935)
    val RED_700 = Color(0xffd32f2f)
    val RED_800 = Color(0xffc62828)
    val RED_900 = Color(0xffb71c1c)

    // RED MATERIAL ACCENT COLORS
    val RED_A100 = Color(0xffff8a80)
    val RED_A200 = Color(0xffff5252)
    val RED_A400 = Color(0xffff1744)
    val RED_A700 = Color(0xffd50000)


    // PINK MATERIAL COLORS
    val PINK = Color(0xffE91E63)
    val PINK_50 = Color(0xffFCE4EC)
    val PINK_100 = Color(0xffF8BBD0)
    val PINK_200 = Color(0xffF48FB1)
    val PINK_300 = Color(0xffF06292)
    val PINK_400 = Color(0xffEC407A)
    val PINK_500 = Color(0xffE91E63)
    val PINK_600 = Color(0xffD81B60)
    val PINK_700 = Color(0xffC2185B)
    val PINK_800 = Color(0xffAD1457)
    val PINK_900 = Color(0xff880E4F)

    // PINK MATERIAL ACCENT COLORS
    val PINK_A100 = Color(0xffFF80AB)
    val PINK_A200 = Color(0xffFF4081)
    val PINK_A400 = Color(0xffF50057)
    val PINK_A700 = Color(0xffC51162)

    // PURPLE MATERIAL COLORS
    val PURPLE = Color(0xff9C27B0)
    val PURPLE_50 = Color(0xffF3E5F5)
    val PURPLE_100 = Color(0xffE1BEE7)
    val PURPLE_200 = Color(0xffCE93D8)
    val PURPLE_300 = Color(0xffBA68C8)
    val PURPLE_400 = Color(0xffAB47BC)
    val PURPLE_500 = Color(0xff9C27B0)
    val PURPLE_600 = Color(0xff8E24AA)
    val PURPLE_700 = Color(0xff7B1FA2)
    val PURPLE_800 = Color(0xff6A1B9A)
    val PURPLE_900 = Color(0xff4A148C)

    // PURPLE MATERIAL ACCENT COLORS
    val PURPLE_A100 = Color(0xffEA80FC)
    val PURPLE_A200 = Color(0xffE040FB)
    val PURPLE_A400 = Color(0xffD500F9)
    val PURPLE_A700 = Color(0xffAA00FF)

    // DEEP PURPLE MATERIAL COLORS
    val DEEP_PURPLE = Color(0xff673AB7)
    val DEEP_PURPLE_50 = Color(0xffEDE7F6)
    val DEEP_PURPLE_100 = Color(0xffD1C4E9)
    val DEEP_PURPLE_200 = Color(0xffB39DDB)
    val DEEP_PURPLE_300 = Color(0xff9575CD)
    val DEEP_PURPLE_400 = Color(0xff7E57C2)
    val DEEP_PURPLE_500 = Color(0xff673AB7)
    val DEEP_PURPLE_600 = Color(0xff5E35B1)
    val DEEP_PURPLE_700 = Color(0xff512DA8)
    val DEEP_PURPLE_800 = Color(0xff4527A0)
    val DEEP_PURPLE_900 = Color(0xff311B92)

    // DEEP PURPLE MATERIAL ACCENT COLORS
    val DEEP_PURPLE_A100 = Color(0xffB388FF)
    val DEEP_PURPLE_A200 = Color(0xff7C4DFF)
    val DEEP_PURPLE_A400 = Color(0xff651FFF)
    val DEEP_PURPLE_A700 = Color(0xff6200EA)


    // INDIGO MATERIAL COLORS
    val INDIGO = Color(0xff3F51B5)
    val INDIGO_50 = Color(0xffE8EAF6)
    val INDIGO_100 = Color(0xffC5CAE9)
    val INDIGO_200 = Color(0xff9FA8DA)
    val INDIGO_300 = Color(0xff7986CB)
    val INDIGO_400 = Color(0xff5C6BC0)
    val INDIGO_500 = Color(0xff3F51B5)
    val INDIGO_600 = Color(0xff3949AB)
    val INDIGO_700 = Color(0xff303F9F)
    val INDIGO_800 = Color(0xff283593)
    val INDIGO_900 = Color(0xff1A237E)

    // INDIGO MATERIAL ACCENT COLORS
    val INDIGO_A100 = Color(0xff8C9EFF)
    val INDIGO_A200 = Color(0xff536DFE)
    val INDIGO_A400 = Color(0xff3D5AFE)
    val INDIGO_A700 = Color(0xff304FFE)

    // BLUE MATERIAL COLORS
    val BLUE = Color(0xff2196F3)
    val BLUE_50 = Color(0xffE3F2FD)
    val BLUE_100 = Color(0xffBBDEFB)
    val BLUE_200 = Color(0xff90CAF9)
    val BLUE_300 = Color(0xff64B5F6)
    val BLUE_400 = Color(0xff42A5F5)
    val BLUE_500 = Color(0xff2196F3)
    val BLUE_600 = Color(0xff1E88E5)
    val BLUE_700 = Color(0xff1976D2)
    val BLUE_800 = Color(0xff1565C0)
    val BLUE_900 = Color(0xff0D47A1)

    // BLUE MATERIAL ACCENT COLORS
    val BLUE_A100 = Color(0xff82B1FF)
    val BLUE_A200 = Color(0xff448AFF)
    val BLUE_A400 = Color(0xff2979FF)
    val BLUE_A700 = Color(0xff2962FF)

    // LIGHT BLUE MATERIAL COLORS
    val LIGHT_BLUE = Color(0xff03A9F4)
    val LIGHT_BLUE_50 = Color(0xffE1F5FE)
    val LIGHT_BLUE_100 = Color(0xffB3E5FC)
    val LIGHT_BLUE_200 = Color(0xff81D4FA)
    val LIGHT_BLUE_300 = Color(0xff4FC3F7)
    val LIGHT_BLUE_400 = Color(0xff29B6F6)
    val LIGHT_BLUE_500 = Color(0xff03A9F4)
    val LIGHT_BLUE_600 = Color(0xff039BE5)
    val LIGHT_BLUE_700 = Color(0xff0288D1)
    val LIGHT_BLUE_800 = Color(0xff0277BD)
    val LIGHT_BLUE_900 = Color(0xff01579B)

    // LIGHT BLUE MATERIAL ACCENT COLORS
    val LIGHT_BLUE_A100 = Color(0xff80D8FF)
    val LIGHT_BLUE_A200 = Color(0xff40C4FF)
    val LIGHT_BLUE_A400 = Color(0xff00B0FF)
    val LIGHT_BLUE_A700 = Color(0xff0091EA)

    // CYAN MATERIAL COLORS
    val CYAN = Color(0xff00BCD4)
    val CYAN_50 = Color(0xffE0F7FA)
    val CYAN_100 = Color(0xffB2EBF2)
    val CYAN_200 = Color(0xff80DEEA)
    val CYAN_300 = Color(0xff4DD0E1)
    val CYAN_400 = Color(0xff26C6DA)
    val CYAN_500 = Color(0xff00BCD4)
    val CYAN_600 = Color(0xff00ACC1)
    val CYAN_700 = Color(0xff0097A7)
    val CYAN_800 = Color(0xff00838F)
    val CYAN_900 = Color(0xff006064)

    // CYAN MATERIAL ACCENT COLORS
    val CYAN_A100 = Color(0xff84FFFF)
    val CYAN_A200 = Color(0xff18FFFF)
    val CYAN_A400 = Color(0xff00E5FF)
    val CYAN_A700 = Color(0xff00B8D4)

    // TEAL MATERIAL COLORS
    val TEAL = Color(0xff009688)
    val TEAL_50 = Color(0xffE0F2F1)
    val TEAL_100 = Color(0xffB2DFDB)
    val TEAL_200 = Color(0xff80CBC4)
    val TEAL_300 = Color(0xff4DB6AC)
    val TEAL_400 = Color(0xff26A69A)
    val TEAL_500 = Color(0xff009688)
    val TEAL_600 = Color(0xff00897B)
    val TEAL_700 = Color(0xff00796B)
    val TEAL_800 = Color(0xff00695C)
    val TEAL_900 = Color(0xff004D40)

    // TEAL MATERIAL ACCENT COLORS
    val TEAL_A100 = Color(0xffA7FFEB)
    val TEAL_A200 = Color(0xff64FFDA)
    val TEAL_A400 = Color(0xff1DE9B6)
    val TEAL_A700 = Color(0xff00BFA5)

    // GREEN MATERIAL COLORS
    val GREEN = Color(0xff4CAF50)
    val GREEN_50 = Color(0xffE8F5E9)
    val GREEN_100 = Color(0xffC8E6C9)
    val GREEN_200 = Color(0xffA5D6A7)
    val GREEN_300 = Color(0xff81C784)
    val GREEN_400 = Color(0xff66BB6A)
    val GREEN_500 = Color(0xff4CAF50)
    val GREEN_600 = Color(0xff43A047)
    val GREEN_700 = Color(0xff388E3C)
    val GREEN_800 = Color(0xff2E7D32)
    val GREEN_900 = Color(0xff1B5E20)

    // GREEN MATERIAL ACCENT COLORS
    val GREEN_A100 = Color(0xffB9F6CA)
    val GREEN_A200 = Color(0xff69F0AE)
    val GREEN_A400 = Color(0xff00E676)
    val GREEN_A700 = Color(0xff00C853)

    // LIGHT GREEN MATERIAL COLORS
    val LIGHT_GREEN = Color(0xff8BC34A)
    val LIGHT_GREEN_50 = Color(0xffF1F8E9)
    val LIGHT_GREEN_100 = Color(0xffDCEDC8)
    val LIGHT_GREEN_200 = Color(0xffC5E1A5)
    val LIGHT_GREEN_300 = Color(0xffAED581)
    val LIGHT_GREEN_400 = Color(0xff9CCC65)
    val LIGHT_GREEN_500 = Color(0xff8BC34A)
    val LIGHT_GREEN_600 = Color(0xff7CB342)
    val LIGHT_GREEN_700 = Color(0xff689F38)
    val LIGHT_GREEN_800 = Color(0xff558B2F)
    val LIGHT_GREEN_900 = Color(0xff33691E)

    // LIGHT GREEN MATERIAL ACCENT COLORS
    val LIGHT_GREEN_A100 = Color(0xffCCFF90)
    val LIGHT_GREEN_A200 = Color(0xffB2FF59)
    val LIGHT_GREEN_A400 = Color(0xff76FF03)
    val LIGHT_GREEN_A700 = Color(0xff64DD17)

    // LIME MATERIAL COLORS
    val LIME = Color(0xffCDDC39)
    val LIME_50 = Color(0xffF9FBE7)
    val LIME_100 = Color(0xffF0F4C3)
    val LIME_200 = Color(0xffE6EE9C)
    val LIME_300 = Color(0xffDCE775)
    val LIME_400 = Color(0xffD4E157)
    val LIME_500 = Color(0xffCDDC39)
    val LIME_600 = Color(0xffC0CA33)
    val LIME_700 = Color(0xffAFB42B)
    val LIME_800 = Color(0xff9E9D24)
    val LIME_900 = Color(0xff827717)

    // LIME MATERIAL ACCENT COLORS
    val LIME_A100 = Color(0xffF4FF81)
    val LIME_A200 = Color(0xffEEFF41)
    val LIME_A400 = Color(0xffC6FF00)
    val LIME_A700 = Color(0xffAEEA00)

    // YELLOW MATERIAL COLORS
    val YELLOW = Color(0xffFFEB3B)
    val YELLOW_50 = Color(0xffFFFDE7)
    val YELLOW_100 = Color(0xffFFF9C4)
    val YELLOW_200 = Color(0xffFFF59D)
    val YELLOW_300 = Color(0xffFFF176)
    val YELLOW_400 = Color(0xffFFEE58)
    val YELLOW_500 = Color(0xffFFEB3B)
    val YELLOW_600 = Color(0xffFDD835)
    val YELLOW_700 = Color(0xffFBC02D)
    val YELLOW_800 = Color(0xffF9A825)
    val YELLOW_900 = Color(0xffF57F17)

    // YELLOW MATERIAL ACCENT COLORS
    val YELLOW_A100 = Color(0xffFFFF8D)
    val YELLOW_A200 = Color(0xffFFFF00)
    val YELLOW_A400 = Color(0xffFFEA00)
    val YELLOW_A700 = Color(0xffFFD600)

    // AMBER MATERIAL COLORS
    val AMBER = Color(0xffFFC107)
    val AMBER_50 = Color(0xffFFF8E1)
    val AMBER_100 = Color(0xffFFECB3)
    val AMBER_200 = Color(0xffFFE082)
    val AMBER_300 = Color(0xffFFD54F)
    val AMBER_400 = Color(0xffFFCA28)
    val AMBER_500 = Color(0xffFFC107)
    val AMBER_600 = Color(0xffFFB300)
    val AMBER_700 = Color(0xffFFA000)
    val AMBER_800 = Color(0xffFF8F00)
    val AMBER_900 = Color(0xffFF6F00)

    // AMBER MATERIAL ACCENT COLORS
    val AMBER_A100 = Color(0xffFFE57F)
    val AMBER_A200 = Color(0xffFFD740)
    val AMBER_A400 = Color(0xffFFC400)
    val AMBER_A700 = Color(0xffFFAB00)

    // ORANGE MATERIAL COLORS
    val ORANGE = Color(0xffFF9800)
    val ORANGE_50 = Color(0xffFFF3E0)
    val ORANGE_100 = Color(0xffFFE0B2)
    val ORANGE_200 = Color(0xffFFCC80)
    val ORANGE_300 = Color(0xffFFB74D)
    val ORANGE_400 = Color(0xffFFA726)
    val ORANGE_500 = Color(0xffFF9800)
    val ORANGE_600 = Color(0xffFB8C00)
    val ORANGE_700 = Color(0xffF57C00)
    val ORANGE_800 = Color(0xffEF6C00)
    val ORANGE_900 = Color(0xffE65100)

    // ORANGE MATERIAL ACCENT COLORS
    val ORANGE_A100 = Color(0xffFFD180)
    val ORANGE_A200 = Color(0xffFFAB40)
    val ORANGE_A400 = Color(0xffFF9100)
    val ORANGE_A700 = Color(0xffFF6D00)

    // DEEP_ORANGE MATERIAL COLORS
    val DEEP_ORANGE = Color(0xffFF5722)
    val DEEP_ORANGE_50 = Color(0xffFBE9E7)
    val DEEP_ORANGE_100 = Color(0xffFFCCBC)
    val DEEP_ORANGE_200 = Color(0xffFFAB91)
    val DEEP_ORANGE_300 = Color(0xffFF8A65)
    val DEEP_ORANGE_400 = Color(0xffFF7043)
    val DEEP_ORANGE_500 = Color(0xffFF5722)
    val DEEP_ORANGE_600 = Color(0xffF4511E)
    val DEEP_ORANGE_700 = Color(0xffE64A19)
    val DEEP_ORANGE_800 = Color(0xffD84315)
    val DEEP_ORANGE_900 = Color(0xffBF360C)

    // DEEP_ORANGE MATERIAL ACCENT COLORS
    val DEEP_ORANGE_A100 = Color(0xffFF9E80)
    val DEEP_ORANGE_A200 = Color(0xffFF6E40)
    val DEEP_ORANGE_A400 = Color(0xffFF3D00)
    val DEEP_ORANGE_A700 = Color(0xffDD2C00)

    // BROWN MATERIAL COLORS
    val BROWN = Color(0xff795548)
    val BROWN_50 = Color(0xffEFEBE9)
    val BROWN_100 = Color(0xffD7CCC8)
    val BROWN_200 = Color(0xffBCAAA4)
    val BROWN_300 = Color(0xffA1887F)
    val BROWN_400 = Color(0xff8D6E63)
    val BROWN_500 = Color(0xff795548)
    val BROWN_600 = Color(0xff6D4C41)
    val BROWN_700 = Color(0xff5D4037)
    val BROWN_800 = Color(0xff4E342E)
    val BROWN_900 = Color(0xff3E2723)

    // GREY MATERIAL COLORS
    val GREY = Color(0xff9E9E9E)
    val GREY_50 = Color(0xffFAFAFA)
    val GREY_100 = Color(0xffF5F5F5)
    val GREY_200 = Color(0xffEEEEEE)
    val GREY_300 = Color(0xffE0E0E0)
    val GREY_400 = Color(0xffBDBDBD)
    val GREY_500 = Color(0xff9E9E9E)
    val GREY_600 = Color(0xff757575)
    val GREY_700 = Color(0xff616161)
    val GREY_800 = Color(0xff424242)
    val GREY_900 = Color(0xff212121)

    // BLUE_GREY MATERIAL COLORS
    val BLUE_GREY = Color(0xff607D8B)
    val BLUE_GREY_50 = Color(0xffECEFF1)
    val BLUE_GREY_100 = Color(0xffCFD8DC)
    val BLUE_GREY_200 = Color(0xffB0BEC5)
    val BLUE_GREY_300 = Color(0xff90A4AE)
    val BLUE_GREY_400 = Color(0xff78909C)
    val BLUE_GREY_500 = Color(0xff607D8B)
    val BLUE_GREY_600 = Color(0xff546E7A)
    val BLUE_GREY_700 = Color(0xff455A64)
    val BLUE_GREY_800 = Color(0xff37474F)
    val BLUE_GREY_900 = Color(0xff263238)


}